@@ -14,6 +14,7 @@ from stat import S_ISREG
 from typing import (
     AbstractSet,
     Any,
+    AsyncGenerator,
     AsyncIterator,
     Awaitable,
     Callable,
@@ -57,7 +58,9 @@ from ._url_utils import (
 )
 from ._users import Action
 from ._utils import (
+    ORG_NAME_SENTINEL,
     NoPublicConstructor,
+    OrgNameSentinel,
     QueuedCall,
     aclosing,
     asyncgeneratorcontextmanager,
@@ -68,7 +71,7 @@ from ._utils import (
 log = logging.getLogger(__package__)
 
 MAX_OPEN_FILES = 20
-READ_SIZE = 2 ** 20  # 1 MiB
+READ_SIZE = 2**20  # 1 MiB
 TIME_THRESHOLD = 1.0
 
 Printer = Callable[[str], None]
@@ -114,6 +117,8 @@ class DiskUsageInfo:
     total: int
     used: int
     free: int
+    org_name: Optional[str] = None
+    uri: Optional[URL] = None
 
 
 @rewrite_module
@@ -218,7 +223,7 @@ class Storage(metaclass=NoPublicConstructor):
             yield uri
             return
         basename = uri.name
-        glob_in_dir: Callable[[URL, str, bool], AsyncIterator[URL]]
+        glob_in_dir: Callable[[URL, str, bool], AsyncGenerator[URL, None]]
         if not _has_magic(basename):
             glob_in_dir = self._glob0
         elif not _isrecursive(basename):
@@ -233,7 +238,7 @@ class Storage(metaclass=NoPublicConstructor):
 
     async def _glob2(
         self, parent: URL, pattern: str, dironly: bool
-    ) -> AsyncIterator[URL]:
+    ) -> AsyncGenerator[URL, None]:
         assert _isrecursive(pattern)
         yield parent
         async with aclosing(self._rlistdir(parent, dironly)) as it:
@@ -242,7 +247,7 @@ class Storage(metaclass=NoPublicConstructor):
 
     async def _glob1(
         self, parent: URL, pattern: str, dironly: bool
-    ) -> AsyncIterator[URL]:
+    ) -> AsyncGenerator[URL, None]:
         allow_hidden = _ishidden(pattern)
         match = re.compile(fnmatch.translate(pattern)).fullmatch
         async with aclosing(self._iterdir(parent, dironly)) as it:
@@ -253,7 +258,7 @@ class Storage(metaclass=NoPublicConstructor):
 
     async def _glob0(
         self, parent: URL, basename: str, dironly: bool
-    ) -> AsyncIterator[URL]:
+    ) -> AsyncGenerator[URL, None]:
         uri = parent / basename
         try:
             await self.stat(uri)
@@ -261,13 +266,15 @@ class Storage(metaclass=NoPublicConstructor):
             return
         yield uri
 
-    async def _iterdir(self, uri: URL, dironly: bool) -> AsyncIterator[FileStatus]:
+    async def _iterdir(
+        self, uri: URL, dironly: bool
+    ) -> AsyncGenerator[FileStatus, None]:
         async with self.list(uri) as it:
             async for stat in it:
                 if not dironly or stat.is_dir():
                     yield stat
 
-    async def _rlistdir(self, uri: URL, dironly: bool) -> AsyncIterator[URL]:
+    async def _rlistdir(self, uri: URL, dironly: bool) -> AsyncGenerator[URL, None]:
         async with aclosing(self._iterdir(uri, dironly)) as it:
             async for stat in it:
                 name = stat.path
@@ -350,13 +357,24 @@ class Storage(metaclass=NoPublicConstructor):
             res = await resp.json()
             return _file_status_from_api_stat(uri.host, res["FileStatus"])
 
-    async def disk_usage(self, cluster_name: Optional[str] = None) -> DiskUsageInfo:
+    async def disk_usage(
+        self,
+        cluster_name: Optional[str] = None,
+        org_name: Union[Optional[str], OrgNameSentinel] = ORG_NAME_SENTINEL,
+        uri: Optional[URL] = None,
+    ) -> DiskUsageInfo:
         cluster_name = cluster_name or self._config.cluster_name
-        uri = self._normalize_uri(
-            URL(f"storage://{cluster_name}/{self._config.username}")
+        org_name_val = (
+            org_name
+            if not isinstance(org_name, OrgNameSentinel)
+            else self._config.org_name
         )
-        assert uri.host is not None
-        url = self._get_storage_url(uri, normalized=True)
+        if uri:
+            url = self._get_storage_url(uri)
+        else:
+            url = self._get_storage_url(
+                self._create_disk_usage_uri(cluster_name, org_name_val), normalized=True
+            )
         url = url.with_query(op="GETDISKUSAGE")
         auth = await self._config._api_auth()
 
@@ -364,7 +382,21 @@ class Storage(metaclass=NoPublicConstructor):
         async with self._core.request("GET", url, auth=auth) as resp:
             self._set_time_diff(request_time, resp)
             res = await resp.json()
-            return _disk_usage_from_api(uri.host, res)
+            return _disk_usage_from_api(cluster_name, org_name_val, uri, res)
+
+    def _create_disk_usage_uri(
+        self, cluster_name: Optional[str], org_name: Optional[str]
+    ) -> URL:
+        if org_name:
+            uri = self._normalize_uri(
+                URL(f"storage://{cluster_name}/{org_name}/{self._config.username}")
+            )
+        else:
+            uri = self._normalize_uri(
+                URL(f"storage://{cluster_name}/{self._config.username}")
+            )
+        assert uri.host is not None
+        return uri
 
     @asyncgeneratorcontextmanager
     async def open(
@@ -951,9 +983,16 @@ def _file_status_from_api_stat(cluster_name: str, values: Dict[str, Any]) -> Fil
     )
 
 
-def _disk_usage_from_api(cluster_name: str, values: Dict[str, Any]) -> DiskUsageInfo:
+def _disk_usage_from_api(
+    cluster_name: str,
+    org_name: Optional[str],
+    uri: Optional[URL],
+    values: Dict[str, Any],
+) -> DiskUsageInfo:
     return DiskUsageInfo(
         cluster_name=cluster_name,
+        org_name=org_name,
+        uri=uri,
         total=values["total"],
         used=values["used"],
         free=values["free"],
@@ -998,7 +1037,7 @@ async def run_progress(
 
 async def run_concurrently(coros: Iterable[Awaitable[Any]]) -> None:
     loop = asyncio.get_event_loop()
-    tasks: "Iterable[asyncio.Future[Any]]" = [loop.create_task(coro) for coro in coros]
+    tasks: "Iterable[asyncio.Future[Any]]" = [loop.create_task(coro) for coro in coros]  # type: ignore  # noqa
     if not tasks:
         return
     try:
